@@ -27,8 +27,20 @@
 
 void nwipe_device_identify( nwipe_context_t* c );  // Get hardware information about the device.
 int nwipe_device_scan( nwipe_context_t*** c );  // Find devices that we can wipe.
+
+/**
+ * Gets information about devices
+ *
+ * @parameter device_names  A reference to a null array pointer.
+ * @parameter devnamelist   An array of string pointers to the device names
+ * @parameter ndevnames     Number of elements in devnamelist
+ * @modifies  device_names  Populates device_names with an array of nwipe_contect_t
+ * @returns                 The number of strings in the device_names array.
+ *
+ */
 int nwipe_device_get( nwipe_context_t*** c, char** devnamelist, int ndevnames );  // Get info about devices to wipe.
-int nwipe_get_device_bus_type_and_serialno( char*, nwipe_device_t*, char* );
+
+int nwipe_get_device_bus_type_and_serialno( char*, nwipe_device_t*, int*, char* );
 void strip_CR_LF( char* );
 void determine_disk_capacity_nomenclature( u64, char* );
 void remove_ATA_prefix( char* );
