@@ -32,10 +32,9 @@ typedef  struct randctx  randctx;
  If (flag==TRUE), then use the contents of randrsl[0..RANDSIZ-1] as the seed.
 ------------------------------------------------------------------------------
 */
-void randinit(/*_ randctx *r, word flag _*/);
-
-void isaac(/*_ randctx *r _*/);
+void randinit(randctx *r, word flag);
 
+void isaac(randctx *r);
 
 /*
 ------------------------------------------------------------------------------
