@@ -386,6 +386,11 @@ int nwipe_options_parse( int argc, char** argv )
                     nwipe_options.method = &nwipe_is5enh;
                     break;
                 }
+                if( strcmp( optarg, "bruce7" ) == 0 )
+                {
+                    nwipe_options.method = &nwipe_bruce7;
+                    break;
+                }
 
                 /* Else we do not know this wipe method. */
                 fprintf( stderr, "Error: Unknown wipe method '%s'.\n", optarg );
@@ -605,37 +610,25 @@ void nwipe_options_log( void )
     {
         nwipe_log( NWIPE_LOG_NOTICE, "  prng     = Mersenne Twister" );
     }
+    else if( nwipe_options.prng == &nwipe_add_lagg_fibonacci_prng )
+    {
+        nwipe_log( NWIPE_LOG_NOTICE, "  prng     = Lagged Fibonacci generator" );
+    }
+    else if( nwipe_options.prng == &nwipe_xoroshiro256_prng )
+    {
+        nwipe_log( NWIPE_LOG_NOTICE, "  prng     = XORoshiro-256" );
+    }
+    else if( nwipe_options.prng == &nwipe_isaac )
+    {
+        nwipe_log( NWIPE_LOG_NOTICE, "  prng     = Isaac" );
+    }
+    else if( nwipe_options.prng == &nwipe_isaac64 )
+    {
+        nwipe_log( NWIPE_LOG_NOTICE, "  prng     = Isaac64" );
+    }
     else
     {
-        if( nwipe_options.prng == &nwipe_add_lagg_fibonacci_prng )
-        {
-            nwipe_log( NWIPE_LOG_NOTICE, "  prng     = Lagged Fibonacci generator (EXPERIMENTAL!)" );
-        }
-        else
-        {
-            if( nwipe_options.prng == &nwipe_xoroshiro256_prng )
-            {
-                nwipe_log( NWIPE_LOG_NOTICE, "  prng     = XORoshiro-256 (EXPERIMENTAL!)" );
-            }
-            else
-            {
-                if( nwipe_options.prng == &nwipe_isaac )
-                {
-                    nwipe_log( NWIPE_LOG_NOTICE, "  prng     = Isaac" );
-                }
-                else
-                {
-                    if( nwipe_options.prng == &nwipe_isaac64 )
-                    {
-                        nwipe_log( NWIPE_LOG_NOTICE, "  prng     = Isaac64" );
-                    }
-                    else
-                    {
-                        nwipe_log( NWIPE_LOG_NOTICE, "  prng     = Undefined" );
-                    }
-                }
-            }
-        }
+        nwipe_log( NWIPE_LOG_NOTICE, "  prng     = Undefined" );
     }
 
     nwipe_log( NWIPE_LOG_NOTICE, "  method   = %s", nwipe_method_label( nwipe_options.method ) );
@@ -710,11 +703,13 @@ void display_help()
     puts( "                          one                    - Overwrite with ones (0xFF)" );
     puts( "                          verify_zero            - Verifies disk is zero filled" );
     puts( "                          verify_one             - Verifies disk is 0xFF filled" );
-    puts( "                          is5enh                 - HMG IS5 enhanced\n" );
+    puts( "                          is5enh                 -  HMG IS5 enhanced\n" );
+    puts( "                          bruce7                 -  Schneier Bruce 7-pass mixed pattern\n" );
     puts( "  -l, --logfile=FILE      Filename to log to. Default is STDOUT\n" );
     puts( "  -P, --PDFreportpath=PATH Path to write PDF reports to. Default is \".\"" );
     puts( "                           If set to \"noPDF\" no PDF reports are written.\n" );
-    puts( "  -p, --prng=METHOD       PRNG option (mersenne|twister|isaac|isaac64|add_lagg_fibonacci_prng)\n" );
+    puts( "  -p, --prng=METHOD       PRNG option "
+          "(mersenne|twister|isaac|isaac64|add_lagg_fibonacci_prng|xoroshiro256_prng)\n" );
     puts( "  -q, --quiet             Anonymize logs and the GUI by removing unique data, i.e." );
     puts( "                          serial numbers, LU WWN Device ID, and SMBIOS/DMI data" );
     puts( "                          XXXXXX = S/N exists, ????? = S/N not obtainable\n" );
