@@ -35,9 +35,10 @@
 #define NWIPE_KNOB_SCSI "/proc/scsi/scsi"
 #define NWIPE_KNOB_SLEEP 1
 #define NWIPE_KNOB_STAT "/proc/stat"
-#define MAX_NUMBER_EXCLUDED_DRIVES 10
+#define MAX_NUMBER_EXCLUDED_DRIVES 32
 #define MAX_DRIVE_PATH_LENGTH 200  // e.g. /dev/sda is only 8 characters long, so 200 should be plenty.
 #define DEFAULT_SYNC_RATE 100000
+#define PATHNAME_MAX 2048
 
 /* Function prototypes for loading options from the environment and command line. */
 int nwipe_options_parse( int argc, char** argv );
@@ -58,12 +59,15 @@ typedef struct
     char* banner;  // The product banner shown on the top line of the screen.
     void* method;  // A function pointer to the wipe method that will be used.
     char logfile[FILENAME_MAX];  // The filename to log the output to.
+    char PDFreportpath[PATHNAME_MAX];  // The path to write the PDF report to.
     char exclude[MAX_NUMBER_EXCLUDED_DRIVES][MAX_DRIVE_PATH_LENGTH];  // Drives excluded from the search.
-    nwipe_prng_t* prng;  // The pseudo random number generator implementation.
+    nwipe_prng_t* prng;  // The pseudo random number generator implementation. pointer to the function.
     int quiet;  // Anonymize serial numbers
     int rounds;  // The number of times that the wipe method should be called.
     int sync;  // A flag to indicate whether and how often writes should be sync'd.
     int verbose;  // Make log more verbose
+    int PDF_enable;  // 0=PDF creation disabled, 1=PDF creation enabled
+    int PDF_preview_details;  // 0=Disable preview Org/Cust/date/time before drive selection, 1=Enable Preview
     nwipe_verify_t verify;  // A flag to indicate whether writes should be verified.
 } nwipe_options_t;
 
