@@ -127,7 +127,6 @@ int nwipe_random_verify( nwipe_context_t* c )
 
     if( r != 0 )
     {
-        /* FIXME: Is there a better way to handle this? */
         nwipe_perror( errno, __FUNCTION__, "fdatasync" );
         nwipe_log( NWIPE_LOG_WARNING, "Buffer flush failure on '%s'.", c->device_name );
         c->fsyncdata_errors++;
@@ -325,7 +324,7 @@ int nwipe_random_pass( NWIPE_METHOD_SIGNATURE )
         /* For the first block only, check the prng actually wrote something to the buffer */
         if( z == c->device_size )
         {
-            idx = c->device_stat.st_blksize;
+            idx = c->device_stat.st_blksize - 1;
             while( idx > 0 )
             {
                 if( b[idx] != 0 )
@@ -338,6 +337,10 @@ int nwipe_random_pass( NWIPE_METHOD_SIGNATURE )
             if( idx == 0 )
             {
                 nwipe_log( NWIPE_LOG_FATAL, "ERROR, prng wrote nothing to the buffer" );
+                if( c->bytes_erased < ( c->device_size - z ) )  // How much of the device has been erased?
+                {
+                    c->bytes_erased = c->device_size - z;
+                }
                 return -1;
             }
         }
@@ -350,6 +353,10 @@ int nwipe_random_pass( NWIPE_METHOD_SIGNATURE )
         {
             nwipe_perror( errno, __FUNCTION__, "write" );
             nwipe_log( NWIPE_LOG_FATAL, "Unable to read from '%s'.", c->device_name );
+            if( c->bytes_erased < ( c->device_size - z ) )  // How much of the device has been erased?
+            {
+                c->bytes_erased = c->device_size - z;
+            }
             return -1;
         }
 
@@ -374,6 +381,10 @@ int nwipe_random_pass( NWIPE_METHOD_SIGNATURE )
                 nwipe_perror( errno, __FUNCTION__, "lseek" );
                 nwipe_log(
                     NWIPE_LOG_ERROR, "Unable to bump the '%s' file offset after a partial write.", c->device_name );
+                if( c->bytes_erased < ( c->device_size - z ) )  // How much of the device has been erased?
+                {
+                    c->bytes_erased = c->device_size - z;
+                }
                 return -1;
             }
 
@@ -409,6 +420,10 @@ int nwipe_random_pass( NWIPE_METHOD_SIGNATURE )
                     nwipe_log( NWIPE_LOG_WARNING, "Wrote %llu bytes on '%s'.", c->pass_done, c->device_name );
                     c->fsyncdata_errors++;
                     free( b );
+                    if( c->bytes_erased < ( c->device_size - z ) )  // How much of the device has been erased?
+                    {
+                        c->bytes_erased = c->device_size - z;
+                    }
                     return -1;
                 }
 
@@ -418,7 +433,13 @@ int nwipe_random_pass( NWIPE_METHOD_SIGNATURE )
 
         pthread_testcancel();
 
-    } /* remaining bytes */
+        /* If statement required so that it does not reset on subsequent passes */
+        if( c->bytes_erased < ( c->device_size - z ) )  // How much of the device has been erased?
+        {
+            c->bytes_erased = c->device_size - z;
+        }
+
+    } /* /remaining bytes */
 
     /* Release the output buffer. */
     free( b );
@@ -434,10 +455,14 @@ int nwipe_random_pass( NWIPE_METHOD_SIGNATURE )
 
     if( r != 0 )
     {
-        /* FIXME: Is there a better way to handle this? */
         nwipe_perror( errno, __FUNCTION__, "fdatasync" );
         nwipe_log( NWIPE_LOG_WARNING, "Buffer flush failure on '%s'.", c->device_name );
         c->fsyncdata_errors++;
+        if( c->bytes_erased < ( c->device_size - z - blocksize ) )  // How much of the device has been erased?
+        {
+            c->bytes_erased = c->device_size - z - blocksize;
+        }
+        return -1;
     }
 
     /* We're done. */
@@ -529,7 +554,6 @@ int nwipe_static_verify( NWIPE_METHOD_SIGNATURE, nwipe_pattern_t* pattern )
 
     if( r != 0 )
     {
-        /* FIXME: Is there a better way to handle this? */
         nwipe_perror( errno, __FUNCTION__, "fdatasync" );
         nwipe_log( NWIPE_LOG_WARNING, "Buffer flush failure on '%s'.", c->device_name );
         c->fsyncdata_errors++;
@@ -761,6 +785,10 @@ int nwipe_static_pass( NWIPE_METHOD_SIGNATURE, nwipe_pattern_t* pattern )
         {
             nwipe_perror( errno, __FUNCTION__, "write" );
             nwipe_log( NWIPE_LOG_FATAL, "Unable to write to '%s'.", c->device_name );
+            if( c->bytes_erased < ( c->device_size - z ) )  // How much of the device has been erased?
+            {
+                c->bytes_erased = c->device_size - z;
+            }
             return -1;
         }
 
@@ -785,6 +813,10 @@ int nwipe_static_pass( NWIPE_METHOD_SIGNATURE, nwipe_pattern_t* pattern )
                 nwipe_perror( errno, __FUNCTION__, "lseek" );
                 nwipe_log(
                     NWIPE_LOG_ERROR, "Unable to bump the '%s' file offset after a partial write.", c->device_name );
+                if( c->bytes_erased < ( c->device_size - z ) )  // How much of the device has been erased?
+                {
+                    c->bytes_erased = c->device_size - z;
+                }
                 return -1;
             }
 
@@ -829,6 +861,10 @@ int nwipe_static_pass( NWIPE_METHOD_SIGNATURE, nwipe_pattern_t* pattern )
                     nwipe_log( NWIPE_LOG_WARNING, "Wrote %llu bytes on '%s'.", c->pass_done, c->device_name );
                     c->fsyncdata_errors++;
                     free( b );
+                    if( c->bytes_erased < ( c->device_size - z ) )  // How much of the device has been erased?
+                    {
+                        c->bytes_erased = c->device_size - z;
+                    }
                     return -1;
                 }
 
@@ -838,7 +874,12 @@ int nwipe_static_pass( NWIPE_METHOD_SIGNATURE, nwipe_pattern_t* pattern )
 
         pthread_testcancel();
 
-    } /* remaining bytes */
+        if( c->bytes_erased < ( c->device_size - z ) )  // How much of the device has been erased?
+        {
+            c->bytes_erased = c->device_size - z;
+        }
+
+    } /* /remaining bytes */
 
     /* Tell our parent that we are syncing the device. */
     c->sync_status = 1;
@@ -851,10 +892,14 @@ int nwipe_static_pass( NWIPE_METHOD_SIGNATURE, nwipe_pattern_t* pattern )
 
     if( r != 0 )
     {
-        /* FIXME: Is there a better way to handle this? */
         nwipe_perror( errno, __FUNCTION__, "fdatasync" );
         nwipe_log( NWIPE_LOG_WARNING, "Buffer flush failure on '%s'.", c->device_name );
         c->fsyncdata_errors++;
+        if( c->bytes_erased < ( c->device_size - z - blocksize ) )  // How much of the device has been erased?
+        {
+            c->bytes_erased = c->device_size - z - blocksize;
+        }
+        return -1;
     }
 
     /* Release the output buffer. */
